/**
 * @file    hbmc_reva_regs.h
 * @brief   Registers, Bit Masks and Bit Positions for the HBMC Peripheral Module.
 */

/* ****************************************************************************
 * Copyright (C) 2016 Maxim Integrated Products, Inc., All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL MAXIM INTEGRATED BE LIABLE FOR ANY CLAIM, DAMAGES
 * OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 * Except as contained in this notice, the name of Maxim Integrated
 * Products, Inc. shall not be used except as stated in the Maxim Integrated
 * Products, Inc. Branding Policy.
 *
 * The mere transfer of this software does not imply any licenses
 * of trade secrets, proprietary technology, copyrights, patents,
 * trademarks, maskwork rights, or any other form of intellectual
 * property whatsoever. Maxim Integrated Products, Inc. retains all
 * ownership rights.
 *
 *
 *************************************************************************** */

#ifndef _HBMC_REVA_REGS_H_
#define _HBMC_REVA_REGS_H_

/* **** Includes **** */
#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif
 
#if defined (__ICCARM__)
  #pragma system_include
#endif
 
#if defined (__CC_ARM)
  #pragma anon_unions
#endif
/// @cond
/*
    If types are not defined elsewhere (CMSIS) define them here
*/
#ifndef __IO
#define __IO volatile
#endif
#ifndef __I
#define __I  volatile const
#endif
#ifndef __O
#define __O  volatile
#endif
#ifndef __R
#define __R  volatile const
#endif
/// @endcond

/* **** Definitions **** */
typedef struct {
    __IO uint32_t status;               /**< <tt>\b 0x00:</tt> HBMC STATUS Register */
    __IO uint32_t inten;                /**< <tt>\b 0x04:</tt> HBMC INTEN Register */
    __IO uint32_t intfl;                /**< <tt>\b 0x08:</tt> HBMC INTFL Register */
    __R  uint32_t rsv_0xc;
    __IO uint32_t mbr[2];               /**< <tt>\b 0x10:</tt> HBMC MBR Register */
    __R  uint32_t rsv_0x18_0x1f[2];
    __IO uint32_t mcr[2];               /**< <tt>\b 0x20:</tt> HBMC MCR Register */
    __R  uint32_t rsv_0x28_0x2f[2];
    __IO uint32_t mtr[2];               /**< <tt>\b 0x30:</tt> HBMC MTR Register */
} mxc_hbmc_reva_regs_t;


/** HBMC RevA Status Register **/
 #define MXC_F_HBMC_REVA_STATUS_RACT_POS                     0 /**< STATUS_RACT Position */
 #define MXC_F_HBMC_REVA_STATUS_RACT                         ((uint32_t)(0x1UL << MXC_F_HBMC_REVA_STATUS_RACT_POS)) /**< STATUS_RACT Mask */
 #define MXC_V_HBMC_REVA_STATUS_RACT_NOREAD                  ((uint32_t)0x0UL) /**< STATUS_RACT_NOREAD Value */
 #define MXC_S_HBMC_REVA_STATUS_RACT_NOREAD                  (MXC_V_HBMC_REVA_STATUS_RACT_NOREAD << MXC_F_HBMC_REVA_STATUS_RACT_POS) /**< STATUS_RACT_NOREAD Setting */
 #define MXC_V_HBMC_REVA_STATUS_RACT_READ                    ((uint32_t)0x1UL) /**< STATUS_RACT_READ Value */
 #define MXC_S_HBMC_REVA_STATUS_RACT_READ                    (MXC_V_HBMC_REVA_STATUS_RACT_READ << MXC_F_HBMC_REVA_STATUS_RACT_POS) /**< STATUS_RACT_READ Setting */

 #define MXC_F_HBMC_REVA_STATUS_RDECERR_POS                  8 /**< STATUS_RDECERR Position */
 #define MXC_F_HBMC_REVA_STATUS_RDECERR                      ((uint32_t)(0x1UL << MXC_F_HBMC_REVA_STATUS_RDECERR_POS)) /**< STATUS_RDECERR Mask */
 #define MXC_V_HBMC_REVA_STATUS_RDECERR_NOERR                ((uint32_t)0x0UL) /**< STATUS_RDECERR_NOERR Value */
 #define MXC_S_HBMC_REVA_STATUS_RDECERR_NOERR                (MXC_V_HBMC_REVA_STATUS_RDECERR_NOERR << MXC_F_HBMC_REVA_STATUS_RDECERR_POS) /**< STATUS_RDECERR_NOERR Setting */
 #define MXC_V_HBMC_REVA_STATUS_RDECERR_ERR                  ((uint32_t)0x1UL) /**< STATUS_RDECERR_ERR Value */
 #define MXC_S_HBMC_REVA_STATUS_RDECERR_ERR                  (MXC_V_HBMC_REVA_STATUS_RDECERR_ERR << MXC_F_HBMC_REVA_STATUS_RDECERR_POS) /**< STATUS_RDECERR_ERR Setting */

 #define MXC_F_HBMC_REVA_STATUS_RRSTOERR_POS                 10 /**< STATUS_RRSTOERR Position */
 #define MXC_F_HBMC_REVA_STATUS_RRSTOERR                     ((uint32_t)(0x1UL << MXC_F_HBMC_REVA_STATUS_RRSTOERR_POS)) /**< STATUS_RRSTOERR Mask */
 #define MXC_V_HBMC_REVA_STATUS_RRSTOERR_NOERR               ((uint32_t)0x0UL) /**< STATUS_RRSTOERR_NOERR Value */
 #define MXC_S_HBMC_REVA_STATUS_RRSTOERR_NOERR               (MXC_V_HBMC_REVA_STATUS_RRSTOERR_NOERR << MXC_F_HBMC_REVA_STATUS_RRSTOERR_POS) /**< STATUS_RRSTOERR_NOERR Setting */
 #define MXC_V_HBMC_REVA_STATUS_RRSTOERR_ERR                 ((uint32_t)0x1UL) /**< STATUS_RRSTOERR_ERR Value */
 #define MXC_S_HBMC_REVA_STATUS_RRSTOERR_ERR                 (MXC_V_HBMC_REVA_STATUS_RRSTOERR_ERR << MXC_F_HBMC_REVA_STATUS_RRSTOERR_POS) /**< STATUS_RRSTOERR_ERR Setting */

 #define MXC_F_HBMC_REVA_STATUS_RDSSTALL_POS                 11 /**< STATUS_RDSSTALL Position */
 #define MXC_F_HBMC_REVA_STATUS_RDSSTALL                     ((uint32_t)(0x1UL << MXC_F_HBMC_REVA_STATUS_RDSSTALL_POS)) /**< STATUS_RDSSTALL Mask */
 #define MXC_V_HBMC_REVA_STATUS_RDSSTALL_NORMALOP            ((uint32_t)0x0UL) /**< STATUS_RDSSTALL_NORMALOP Value */
 #define MXC_S_HBMC_REVA_STATUS_RDSSTALL_NORMALOP            (MXC_V_HBMC_REVA_STATUS_RDSSTALL_NORMALOP << MXC_F_HBMC_REVA_STATUS_RDSSTALL_POS) /**< STATUS_RDSSTALL_NORMALOP Setting */
 #define MXC_V_HBMC_REVA_STATUS_RDSSTALL_STALLED             ((uint32_t)0x1UL) /**< STATUS_RDSSTALL_STALLED Value */
 #define MXC_S_HBMC_REVA_STATUS_RDSSTALL_STALLED             (MXC_V_HBMC_REVA_STATUS_RDSSTALL_STALLED << MXC_F_HBMC_REVA_STATUS_RDSSTALL_POS) /**< STATUS_RDSSTALL_STALLED Setting */

 #define MXC_F_HBMC_REVA_STATUS_WACT_POS                     16 /**< STATUS_WACT Position */
 #define MXC_F_HBMC_REVA_STATUS_WACT                         ((uint32_t)(0x1UL << MXC_F_HBMC_REVA_STATUS_WACT_POS)) /**< STATUS_WACT Mask */
 #define MXC_V_HBMC_REVA_STATUS_WACT_NOWRITE                 ((uint32_t)0x0UL) /**< STATUS_WACT_NOWRITE Value */
 #define MXC_S_HBMC_REVA_STATUS_WACT_NOWRITE                 (MXC_V_HBMC_REVA_STATUS_WACT_NOWRITE << MXC_F_HBMC_REVA_STATUS_WACT_POS) /**< STATUS_WACT_NOWRITE Setting */
 #define MXC_V_HBMC_REVA_STATUS_WACT_WRITE                   ((uint32_t)0x1UL) /**< STATUS_WACT_WRITE Value */
 #define MXC_S_HBMC_REVA_STATUS_WACT_WRITE                   (MXC_V_HBMC_REVA_STATUS_WACT_WRITE << MXC_F_HBMC_REVA_STATUS_WACT_POS) /**< STATUS_WACT_WRITE Setting */

 #define MXC_F_HBMC_REVA_STATUS_WDECERR_POS                  24 /**< STATUS_WDECERR Position */
 #define MXC_F_HBMC_REVA_STATUS_WDECERR                      ((uint32_t)(0x1UL << MXC_F_HBMC_REVA_STATUS_WDECERR_POS)) /**< STATUS_WDECERR Mask */
 #define MXC_V_HBMC_REVA_STATUS_WDECERR_NOERR                ((uint32_t)0x0UL) /**< STATUS_WDECERR_NOERR Value */
 #define MXC_S_HBMC_REVA_STATUS_WDECERR_NOERR                (MXC_V_HBMC_REVA_STATUS_WDECERR_NOERR << MXC_F_HBMC_REVA_STATUS_WDECERR_POS) /**< STATUS_WDECERR_NOERR Setting */
 #define MXC_V_HBMC_REVA_STATUS_WDECERR_ERR                  ((uint32_t)0x1UL) /**< STATUS_WDECERR_ERR Value */
 #define MXC_S_HBMC_REVA_STATUS_WDECERR_ERR                  (MXC_V_HBMC_REVA_STATUS_WDECERR_ERR << MXC_F_HBMC_REVA_STATUS_WDECERR_POS) /**< STATUS_WDECERR_ERR Setting */

 #define MXC_F_HBMC_REVA_STATUS_WRSTOERR_POS                 26 /**< STATUS_WRSTOERR Position */
 #define MXC_F_HBMC_REVA_STATUS_WRSTOERR                     ((uint32_t)(0x1UL << MXC_F_HBMC_REVA_STATUS_WRSTOERR_POS)) /**< STATUS_WRSTOERR Mask */
 #define MXC_V_HBMC_REVA_STATUS_WRSTOERR_NOERR               ((uint32_t)0x0UL) /**< STATUS_WRSTOERR_NOERR Value */
 #define MXC_S_HBMC_REVA_STATUS_WRSTOERR_NOERR               (MXC_V_HBMC_REVA_STATUS_WRSTOERR_NOERR << MXC_F_HBMC_REVA_STATUS_WRSTOERR_POS) /**< STATUS_WRSTOERR_NOERR Setting */
 #define MXC_V_HBMC_REVA_STATUS_WRSTOERR_ERR                 ((uint32_t)0x1UL) /**< STATUS_WRSTOERR_ERR Value */
 #define MXC_S_HBMC_REVA_STATUS_WRSTOERR_ERR                 (MXC_V_HBMC_REVA_STATUS_WRSTOERR_ERR << MXC_F_HBMC_REVA_STATUS_WRSTOERR_POS) /**< STATUS_WRSTOERR_ERR Setting */


/** HBMC RevA Interrupt Enable Register **/
 #define MXC_F_HBMC_REVA_INTEN_ERRINTE_POS                   1 /**< INTEN_ERRINTE Position */
 #define MXC_F_HBMC_REVA_INTEN_ERRINTE                       ((uint32_t)(0x1UL << MXC_F_HBMC_REVA_INTEN_ERRINTE_POS)) /**< INTEN_ERRINTE Mask */
 #define MXC_V_HBMC_REVA_INTEN_ERRINTE_DIS                   ((uint32_t)0x0UL) /**< INTEN_ERRINTE_DIS Value */
 #define MXC_S_HBMC_REVA_INTEN_ERRINTE_DIS                   (MXC_V_HBMC_REVA_INTEN_ERRINTE_DIS << MXC_F_HBMC_REVA_INTEN_ERRINTE_POS) /**< INTEN_ERRINTE_DIS Setting */
 #define MXC_V_HBMC_REVA_INTEN_ERRINTE_EN                    ((uint32_t)0x1UL) /**< INTEN_ERRINTE_EN Value */
 #define MXC_S_HBMC_REVA_INTEN_ERRINTE_EN                    (MXC_V_HBMC_REVA_INTEN_ERRINTE_EN << MXC_F_HBMC_REVA_INTEN_ERRINTE_POS) /**< INTEN_ERRINTE_EN Setting */


/** HBMC RevA Interrupt Status Flags Register **/
 #define MXC_F_HBMC_REVA_INTFL_ERRINT_POS                    1 /**< INTFL_ERRINT Position */
 #define MXC_F_HBMC_REVA_INTFL_ERRINT                        ((uint32_t)(0x1UL << MXC_F_HBMC_REVA_INTFL_ERRINT_POS)) /**< INTFL_ERRINT Mask */
 #define MXC_V_HBMC_REVA_INTFL_ERRINT_NOINT                  ((uint32_t)0x0UL) /**< INTFL_ERRINT_NOINT Value */
 #define MXC_S_HBMC_REVA_INTFL_ERRINT_NOINT                  (MXC_V_HBMC_REVA_INTFL_ERRINT_NOINT << MXC_F_HBMC_REVA_INTFL_ERRINT_POS) /**< INTFL_ERRINT_NOINT Setting */
 #define MXC_V_HBMC_REVA_INTFL_ERRINT_PENDING                ((uint32_t)0x1UL) /**< INTFL_ERRINT_PENDING Value */
 #define MXC_S_HBMC_REVA_INTFL_ERRINT_PENDING                (MXC_V_HBMC_REVA_INTFL_ERRINT_PENDING << MXC_F_HBMC_REVA_INTFL_ERRINT_POS) /**< INTFL_ERRINT_PENDING Setting */


/** HBMC RevA Memory Base Address Register **/
 #define MXC_F_HBMC_REVA_MBR_ADDR_POS                        24 /**< MBR_ADDR Position */
 #define MXC_F_HBMC_REVA_MBR_ADDR                            ((uint32_t)(0xFFUL << MXC_F_HBMC_REVA_MBR_ADDR_POS)) /**< MBR_ADDR Mask */


/** HBMC RevA Memory Configuration Register **/
 #define MXC_F_HBMC_REVA_MCR_DEV_TYPE_POS                    3 /**< MCR_DEV_TYPE Position */
 #define MXC_F_HBMC_REVA_MCR_DEV_TYPE                        ((uint32_t)(0x3UL << MXC_F_HBMC_REVA_MCR_DEV_TYPE_POS)) /**< MCR_DEV_TYPE Mask */
 #define MXC_V_HBMC_REVA_MCR_DEV_TYPE_HYPERFLASH             ((uint32_t)0x0UL) /**< MCR_DEV_TYPE_HYPERFLASH Value */
 #define MXC_S_HBMC_REVA_MCR_DEV_TYPE_HYPERFLASH             (MXC_V_HBMC_REVA_MCR_DEV_TYPE_HYPERFLASH << MXC_F_HBMC_REVA_MCR_DEV_TYPE_POS) /**< MCR_DEV_TYPE_HYPERFLASH Setting */
 #define MXC_V_HBMC_REVA_MCR_DEV_TYPE_XCCELAPSRAM            ((uint32_t)0x1UL) /**< MCR_DEV_TYPE_XCCELAPSRAM Value */
 #define MXC_S_HBMC_REVA_MCR_DEV_TYPE_XCCELAPSRAM            (MXC_V_HBMC_REVA_MCR_DEV_TYPE_XCCELAPSRAM << MXC_F_HBMC_REVA_MCR_DEV_TYPE_POS) /**< MCR_DEV_TYPE_XCCELAPSRAM Setting */
 #define MXC_V_HBMC_REVA_MCR_DEV_TYPE_HYPERRAM               ((uint32_t)0x2UL) /**< MCR_DEV_TYPE_HYPERRAM Value */
 #define MXC_S_HBMC_REVA_MCR_DEV_TYPE_HYPERRAM               (MXC_V_HBMC_REVA_MCR_DEV_TYPE_HYPERRAM << MXC_F_HBMC_REVA_MCR_DEV_TYPE_POS) /**< MCR_DEV_TYPE_HYPERRAM Setting */

 #define MXC_F_HBMC_REVA_MCR_CRT_POS                         5 /**< MCR_CRT Position */
 #define MXC_F_HBMC_REVA_MCR_CRT                             ((uint32_t)(0x1UL << MXC_F_HBMC_REVA_MCR_CRT_POS)) /**< MCR_CRT Mask */
 #define MXC_V_HBMC_REVA_MCR_CRT_MEM_SPACE                   ((uint32_t)0x0UL) /**< MCR_CRT_MEM_SPACE Value */
 #define MXC_S_HBMC_REVA_MCR_CRT_MEM_SPACE                   (MXC_V_HBMC_REVA_MCR_CRT_MEM_SPACE << MXC_F_HBMC_REVA_MCR_CRT_POS) /**< MCR_CRT_MEM_SPACE Setting */
 #define MXC_V_HBMC_REVA_MCR_CRT_CONFIG_REG_SPACE            ((uint32_t)0x1UL) /**< MCR_CRT_CONFIG_REG_SPACE Value */
 #define MXC_S_HBMC_REVA_MCR_CRT_CONFIG_REG_SPACE            (MXC_V_HBMC_REVA_MCR_CRT_CONFIG_REG_SPACE << MXC_F_HBMC_REVA_MCR_CRT_POS) /**< MCR_CRT_CONFIG_REG_SPACE Setting */

 #define MXC_F_HBMC_REVA_MCR_READ_LATENCY_POS                6 /**< MCR_READ_LATENCY Position */
 #define MXC_F_HBMC_REVA_MCR_READ_LATENCY                    ((uint32_t)(0x1UL << MXC_F_HBMC_REVA_MCR_READ_LATENCY_POS)) /**< MCR_READ_LATENCY Mask */
 #define MXC_V_HBMC_REVA_MCR_READ_LATENCY_VARIABLE           ((uint32_t)0x0UL) /**< MCR_READ_LATENCY_VARIABLE Value */
 #define MXC_S_HBMC_REVA_MCR_READ_LATENCY_VARIABLE           (MXC_V_HBMC_REVA_MCR_READ_LATENCY_VARIABLE << MXC_F_HBMC_REVA_MCR_READ_LATENCY_POS) /**< MCR_READ_LATENCY_VARIABLE Setting */
 #define MXC_V_HBMC_REVA_MCR_READ_LATENCY_FIXED              ((uint32_t)0x1UL) /**< MCR_READ_LATENCY_FIXED Value */
 #define MXC_S_HBMC_REVA_MCR_READ_LATENCY_FIXED              (MXC_V_HBMC_REVA_MCR_READ_LATENCY_FIXED << MXC_F_HBMC_REVA_MCR_READ_LATENCY_POS) /**< MCR_READ_LATENCY_FIXED Setting */

 #define MXC_F_HBMC_REVA_MCR_HSE_POS                         7 /**< MCR_HSE Position */
 #define MXC_F_HBMC_REVA_MCR_HSE                             ((uint32_t)(0x1UL << MXC_F_HBMC_REVA_MCR_HSE_POS)) /**< MCR_HSE Mask */
 #define MXC_V_HBMC_REVA_MCR_HSE_DIS                         ((uint32_t)0x0UL) /**< MCR_HSE_DIS Value */
 #define MXC_S_HBMC_REVA_MCR_HSE_DIS                         (MXC_V_HBMC_REVA_MCR_HSE_DIS << MXC_F_HBMC_REVA_MCR_HSE_POS) /**< MCR_HSE_DIS Setting */
 #define MXC_V_HBMC_REVA_MCR_HSE_EN                          ((uint32_t)0x1UL) /**< MCR_HSE_EN Value */
 #define MXC_S_HBMC_REVA_MCR_HSE_EN                          (MXC_V_HBMC_REVA_MCR_HSE_EN << MXC_F_HBMC_REVA_MCR_HSE_POS) /**< MCR_HSE_EN Setting */

 #define MXC_F_HBMC_REVA_MCR_MAXLEN_POS                      18 /**< MCR_MAXLEN Position */
 #define MXC_F_HBMC_REVA_MCR_MAXLEN                          ((uint32_t)(0x1FFUL << MXC_F_HBMC_REVA_MCR_MAXLEN_POS)) /**< MCR_MAXLEN Mask */

 #define MXC_F_HBMC_REVA_MCR_MAXLEN_EN_POS                   31 /**< MCR_MAXLEN_EN Position */
 #define MXC_F_HBMC_REVA_MCR_MAXLEN_EN                       ((uint32_t)(0x1UL << MXC_F_HBMC_REVA_MCR_MAXLEN_EN_POS)) /**< MCR_MAXLEN_EN Mask */
 #define MXC_V_HBMC_REVA_MCR_MAXLEN_EN_DIS                   ((uint32_t)0x0UL) /**< MCR_MAXLEN_EN_DIS Value */
 #define MXC_S_HBMC_REVA_MCR_MAXLEN_EN_DIS                   (MXC_V_HBMC_REVA_MCR_MAXLEN_EN_DIS << MXC_F_HBMC_REVA_MCR_MAXLEN_EN_POS) /**< MCR_MAXLEN_EN_DIS Setting */
 #define MXC_V_HBMC_REVA_MCR_MAXLEN_EN_EN                    ((uint32_t)0x1UL) /**< MCR_MAXLEN_EN_EN Value */
 #define MXC_S_HBMC_REVA_MCR_MAXLEN_EN_EN                    (MXC_V_HBMC_REVA_MCR_MAXLEN_EN_EN << MXC_F_HBMC_REVA_MCR_MAXLEN_EN_POS) /**< MCR_MAXLEN_EN_EN Setting */


/** HBMC RevA Memory Timing Register **/
 #define MXC_F_HBMC_REVA_MTR_LATENCY_POS                     0 /**< MTR_LATENCY Position */
 #define MXC_F_HBMC_REVA_MTR_LATENCY                         ((uint32_t)(0xFUL << MXC_F_HBMC_REVA_MTR_LATENCY_POS)) /**< MTR_LATENCY Mask */

 #define MXC_F_HBMC_REVA_MTR_WCSH_POS                        8 /**< MTR_WCSH Position */
 #define MXC_F_HBMC_REVA_MTR_WCSH                            ((uint32_t)(0xFUL << MXC_F_HBMC_REVA_MTR_WCSH_POS)) /**< MTR_WCSH Mask */

 #define MXC_F_HBMC_REVA_MTR_RCSH_POS                        12 /**< MTR_RCSH Position */
 #define MXC_F_HBMC_REVA_MTR_RCSH                            ((uint32_t)(0xFUL << MXC_F_HBMC_REVA_MTR_RCSH_POS)) /**< MTR_RCSH Mask */

 #define MXC_F_HBMC_REVA_MTR_WCSS_POS                        16 /**< MTR_WCSS Position */
 #define MXC_F_HBMC_REVA_MTR_WCSS                            ((uint32_t)(0xFUL << MXC_F_HBMC_REVA_MTR_WCSS_POS)) /**< MTR_WCSS Mask */

 #define MXC_F_HBMC_REVA_MTR_RCSS_POS                        20 /**< MTR_RCSS Position */
 #define MXC_F_HBMC_REVA_MTR_RCSS                            ((uint32_t)(0xFUL << MXC_F_HBMC_REVA_MTR_RCSS_POS)) /**< MTR_RCSS Mask */

 #define MXC_F_HBMC_REVA_MTR_WCSHI_POS                       24 /**< MTR_WCSHI Position */
 #define MXC_F_HBMC_REVA_MTR_WCSHI                           ((uint32_t)(0xFUL << MXC_F_HBMC_REVA_MTR_WCSHI_POS)) /**< MTR_WCSHI Mask */

 #define MXC_F_HBMC_REVA_MTR_RCSHI_POS                       28 /**< MTR_RCSHI Position */
 #define MXC_F_HBMC_REVA_MTR_RCSHI                           ((uint32_t)(0xFUL << MXC_F_HBMC_REVA_MTR_RCSHI_POS)) /**< MTR_RCSHI Mask */

#ifdef __cplusplus
}
#endif

#endif /* _HBMC_REVA_REGS_H_ */
